lists.pdf

## Metadata

Title | lists.pdf
Path | C:\Users\jenni\OneDrive\Documents\Code\burdoc\burdoc\tests\integration\data\inputs\lists.pdf
Pages | 0
PDF Metadata: format | PDF 1.7
PDF Metadata: title |
PDF Metadata: author | Joe Ennis
PDF Metadata: subject |
PDF Metadata: keywords |
PDF Metadata: creator | Microsoft® Word for Microsoft 365
PDF Metadata: producer | Microsoft® Word for Microsoft 365
PDF Metadata: creationDate | D:20230325090033+00'00'
PDF Metadata: modDate | D:20230325090033+00'00'
PDF Metadata: trapped |
PDF Metadata: encryption |

## Contents

1. Page 0
2. h1 :: Lists

#### Page 0

No images

Path: | content.0.[0,0].bbox
Type: | addition

Key | Old | New
x1 |  | 112.79052734375
y1 |  | 96.10997772216797
y0 |  | 76.06997680664062
x0 |  | 72.02400207519531

Path: | content.0.[1,1].bbox
Type: | addition

Key | Old | New
x1 |  | 280.4811706542969
y1 |  | 414.6143798828125
y0 |  | 112.31396484375
x0 |  | 90.02400207519531

Path: | content.0.[2,2].bbox
Type: | addition

Key | Old | New
x1 |  | 282.4100036621094
y1 |  | 635.8043823242188
y0 |  | 430.0943908691406
x0 |  | 90.02400207519531

Path: | content.0.[3,3].bbox
Type: | addition

Key | Old | New
x1 |  | 524.4873046875
y1 |  | 758.4644165039062
y0 |  | 73.5243911743164
x0 |  | 90.02400207519531

Path: | content.0.[4,4].bbox
Type: | addition

Key | Old | New
x1 |  | 525.4684448242188
y1 |  | 351.7143859863281
y0 |  | 196.16441345214844
x0 |  | 315.42999267578125

# Lists

- Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur non vestibulum augue. Maecenas porta dapibus libero in fringilla. Phasellus suscipit dignissim lacus, eu imperdiet neque tempor vitae.

- Nulla vehicula sapien a urna pellentesque ultricies. Etiam blandit accumsan justo, a sodales risus. Vestibulum vehicula diam malesuada nisi venenatis mollis. Duis finibus ante sit amet congue facilisis. Fusce aliquam lectus a risus pulvinar pretium.

  Maecenas aliquet arcu non iaculis laoreet. Donec accumsan urna eget lacinia dapibus. Sed purus orci, congue at vehicula id, venenatis ut quam. Nam vel sodales ligula, ut sodales nisl.

- Vestibulum justo augue, laoreet sit amet venenatis at, suscipit nec lectus. Sed id augue dapibus, sodales nisl ut, volutpat purus.

1. Fusce luctus, ligula sit amet volutpat

2. pretium, nisi urna ultrices libero, eu

3. vestibulum nunc metus ut neque.

4. Nullam sapien arcu, vestibulum sit amet

5. scelerisque ut, tincidunt eget quam. Aliquam at venenatis urna. Etiam

6. sollicitudin convallis sapien id auctor. Pellentesque non nibh quis massa blandit sollicitudin sit amet eu velit. Duis sollicitudin metus cursus, suscipit

   felis nec, sollicitudin dui. Nullam euismod, lacus vel commodo aliquet, lacus quam aliquam nunc, id faucibus nulla dolor eget lorem. Nunc accumsan maximus est in consequat. In hac habitasse platea dictumst.

1. Ut lacinia augue non quam rhoncus ultricies vel sit amet velit. Nulla convallis id tellus ac tincidunt. Aenean

2. hendrerit posuere rhoncus. Duis facilisis commodo eleifend. Pellentesque ullamcorper congue tincidunt. Duis quis mollis diam, eu

3. aliquet nunc. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per

   inceptos himenaeos. Aenean consectetur sed diam et iaculis. Proin a purus non ante lobortis finibus quis non sapien.

4. Curabitur nec tellus ante. Aenean orci ipsum, pharetra sit amet lacus at, luctus egestas felis. Vivamus dictum pharetra sagittis. Lorem ipsum dolor sit amet,

5. consectetur adipiscing elit. Fusce pretium vitae arcu nec consectetur.

Pellentesque hendrerit venenatis pretium. Aenean bibendum, risus quis rhoncus consectetur, ex quam ullamcorper nibh, imperdiet mattis metus nisl nec sapien. Etiam aliquam libero sed dictum cursus. Mauris in sollicitudin dui. Donec auctor ante nec finibus imperdiet. Morbi vulputate velit ante, vel egestas dolor euismod vel. Proin interdum molestie eros, eget tempor ante. Praesent ligula risus, porta vel turpis quis, pellentesque consectetur nisl. Curabitur varius, arcu at eleifend vestibulum, sapien ante vehicula sem, at porta arcu dolor eget enim. Suspendisse eu tempor eros.

# Lists

- Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur non vestibulum augue. Maecenas porta dapibus libero in fringilla. Phasellus suscipit dignissim lacus, eu imperdiet neque tempor vitae.

- Nulla vehicula sapien a urna pellentesque ultricies. Etiam blandit accumsan justo, a sodales risus. Vestibulum vehicula diam malesuada nisi venenatis mollis. Duis finibus ante sit amet congue facilisis. Fusce aliquam lectus a risus pulvinar pretium.

  Maecenas aliquet arcu non iaculis laoreet. Donec accumsan urna eget lacinia dapibus. Sed purus orci, congue at vehicula id, venenatis ut quam. Nam vel sodales ligula, ut sodales nisl.

- Vestibulum justo augue, laoreet sit amet venenatis at, suscipit nec lectus. Sed id augue dapibus, sodales nisl ut, volutpat purus.

1. Fusce luctus, ligula sit amet volutpat

2. pretium, nisi urna ultrices libero, eu

3. vestibulum nunc metus ut neque.

4. Nullam sapien arcu, vestibulum sit amet

5. scelerisque ut, tincidunt eget quam. Aliquam at venenatis urna. Etiam

6. sollicitudin convallis sapien id auctor. Pellentesque non nibh quis massa blandit sollicitudin sit amet eu velit. Duis sollicitudin metus cursus, suscipit

   felis nec, sollicitudin dui. Nullam euismod, lacus vel commodo aliquet, lacus quam aliquam nunc, id faucibus nulla dolor eget lorem. Nunc accumsan maximus est in consequat. In hac habitasse platea dictumst.

1. Ut lacinia augue non quam rhoncus ultricies vel sit amet velit. Nulla convallis id tellus ac tincidunt. Aenean

2. hendrerit posuere rhoncus. Duis facilisis commodo eleifend. Pellentesque ullamcorper congue tincidunt. Duis quis mollis diam, eu

3. aliquet nunc. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per

   inceptos himenaeos. Aenean consectetur sed diam et iaculis. Proin a purus non ante lobortis finibus quis non sapien.

4. Curabitur nec tellus ante. Aenean orci ipsum, pharetra sit amet lacus at, luctus egestas felis. Vivamus dictum pharetra sagittis. Lorem ipsum dolor sit amet,

5. consectetur adipiscing elit. Fusce pretium vitae arcu nec consectetur.

Pellentesque hendrerit venenatis pretium. Aenean bibendum, risus quis rhoncus consectetur, ex quam ullamcorper nibh, imperdiet mattis metus nisl nec sapien. Etiam aliquam libero sed dictum cursus. Mauris in sollicitudin dui. Donec auctor ante nec finibus imperdiet. Morbi vulputate velit ante, vel egestas dolor euismod vel. Proin interdum molestie eros, eget tempor ante. Praesent ligula risus, porta vel turpis quis, pellentesque consectetur nisl. Curabitur varius, arcu at eleifend vestibulum, sapien ante vehicula sem, at porta arcu dolor eget enim. Suspendisse eu tempor eros.

Parent File Contents